bug-textutils
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

uniq bugs in 2.0.15 release


From: Padraig Brady
Subject: uniq bugs in 2.0.15 release
Date: Mon, 24 Sep 2001 20:33:55 +0100
User-agent: Mozilla/5.0 (X11; U; Linux i686; en-US; rv:0.9.4) Gecko/20010913

Obvious really. Note I used the word prepend rather
than precede as to be consistent with the info docs.
To apply:
cd textutils-2.0.15; patch < uniq-2.0.15-delim.diff

cheers,
Padraig.
--- uniq-2.0.15.c       Mon Sep 24 20:31:55 2001
+++ uniq.c      Mon Sep 24 16:38:50 2001
@@ -87,8 +87,8 @@
   /* No delimiters output.  --all-repeated[=none] */
   DM_NONE,
 
-  /* Delimiter precedes all groups.  --all-repeated=precede */
-  DM_PRECEDE,
+  /* Delimiter precedes all groups.  --all-repeated=prepend */
+  DM_PREPEND,
 
   /* Delimit all groups.  --all-repeated=separate */
   DM_SEPARATE
@@ -96,12 +96,12 @@
 
 static char const *const delimit_method_string[] =
 {
-  "none", "precede", "separate", 0
+  "none", "prepend", "separate", 0
 };
 
 static enum delimit_method const delimit_method_map[] =
 {
-  DM_NONE, DM_PRECEDE, DM_SEPARATE
+  DM_NONE, DM_PREPEND, DM_SEPARATE
 };
 
 /* Select whether/how to delimit groups of duplicate lines.  */
@@ -141,7 +141,7 @@
   -c, --count           prefix lines by the number of occurrences\n\
   -d, --repeated        only print duplicate lines\n\
   -D, --all-repeated[=delimit-method] print all duplicate lines\n\
-                        delimit-method={all,minimum,none(default)}\n\
+                        delimit-method={none(default),prepend,separate)}\n\
                         Delimiting is done with blank lines.\n\
   -f, --skip-fields=N   avoid comparing the first N fields\n\
   -i, --ignore-case     ignore differences in case when comparing\n\
@@ -341,7 +341,7 @@
                }
              else if (match_count == 1)
                {
-                 if ((delimit_groups == DM_PRECEDE)
+                 if ((delimit_groups == DM_PREPEND)
                      || (delimit_groups == DM_SEPARATE
                          && !first_delimiter))
                    putc ('\n', ostream);

reply via email to

[Prev in Thread] Current Thread [Next in Thread]